@@ -1,7 +1,7 @@
 package Devel::Caller::Util;
 
 our $DATE = '2015-07-26'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use warnings;
@@ -17,20 +17,21 @@ sub callers {
     my @res;
     my $i = $start+1;
 
-    if ($with_args) {
-        {
-            package DB;
-            while (my @caller = caller($i)) {
-                $caller[11] = [@DB::args];
-                push @res, \@caller;
-                $i++;
+    while (1) {
+        my @caller;
+        if ($with_args) {
+            {
+                package DB;
+                @caller = caller($i);
+                $caller[11] = [@DB::args] if @caller;
             }
+        } else {
+            @caller = caller($i);
         }
-    } else {
-        while (my @caller = caller($i)) {
-            push @res, \@caller;
-            $i++;
-        }
+        last unless @caller;
+
+        push @res, \@caller;
+        $i++;
     }
 
     @res;
@@ -51,7 +52,7 @@ Devel::Caller::Util - caller()-related utility routines
 
 =head1 VERSION
 
-This document describes version 0.02 of Devel::Caller::Util (from Perl distribution Devel-Caller-Util), released on 2015-07-26.
+This document describes version 0.03 of Devel::Caller::Util (from Perl distribution Devel-Caller-Util), released on 2015-07-26.
 
 =head1 SYNOPSIS
 
